Stan Math Library: stan/math/rev/arr/fun/sum.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
sum.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <vector>`

Go to the source code of this file.

## Classes
class | stan::math::sum_v_vari
| Class for sums of variables constructed with standard vectors. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::sum (const std::vector< var > &m)
| Returns the sum of the entries of the specified vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.